--- page_type: digest portal_name: Wachstumswende portal_url: https://wachstumswende.de/ portal_image_url: https://wachstumswende.de/static/img/logo-icon.png addressee: Vincent topic: Look what happened in the last week! prefs_url: /prefs notification_reason: You are getting this notification because [notification reason]. groups: - group_name: Interested Civilians group_url: /groups/interested-civilians image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/group/c6a50692c282d44f4fdf6437d9298765926a212f.png.200x200_q85_crop-1_upscale-1.png items: - type: doc event_text: new document object_name: A radically condensed history of economism object_url: /objects/a-radically-condensed-history image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/de99caf7793703d38ab3574d289c53dd03738cea.png.263x263_q85_crop-1_upscale-1.jpg - type: event event_text: new event object_name: How to deal with status anxiety object_url: /objects/how-to-deal image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/5d8ad220bb38d9699f7f401fa0029dc193ba8496.png.263x263_q85_crop-1_upscale-1.jpg - type: event event_text: upcoming event event_meta: 21.11.2016 object_name: Wine & cheese & more wine object_url: /objects/how-to-deal object_text: > Tom Tomson received your invitation and was initially extremely hesistant about the whole thing. The thing is, Tom had already heard about Interested civilians and it gave rose to all sorts of envious internal gnashings image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/01db1fcf7f1b1c1bacef7ceb7884bd67fc0de5e3.png.263x263_q85_crop-1_upscale-1.jpg - type: event event_text: new event object_name: How to deal with status anxiety object_url: /objects/how-to-deal image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/5d8ad220bb38d9699f7f401fa0029dc193ba8496.png.263x263_q85_crop-1_upscale-1.jpg - group_name: Friends of Tehran group_url: /groups/interested-civilians image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/group/287cefda8f44921f0e74c8248ae1274d28845f2f.png.200x200_q85_crop-1_upscale-1.jpg items: - type: doc event_text: new document object_name: A million books object_url: /objects/one-million-books image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/6f9453d86f57bfcbd0f5f8a1dcbf093384d1e5a0.png.263x263_q85_crop-1_upscale-1.jpg - type: news event_text: news object_name: Call for fundraising object_url: /objects/calls-for-fundraising image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/01db1fcf7f1b1c1bacef7ceb7884bd67fc0de5e3.png.263x263_q85_crop-1_upscale-1.jpg - type: poll event_text: poll object_name: How well do you know your Hafiz? object_url: /objects/hafiz image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/de99caf7793703d38ab3574d289c53dd03738cea.png.263x263_q85_crop-1_upscale-1.jpg comment: event_text: Jimmy Jimson has commented on the poll event_meta: vor 2 Tagen image_url: https://wechange.de/media/cosinnus_portals/portal_wechange/avatars/user/5d8ad220bb38d9699f7f401fa0029dc193ba8496.png.263x263_q85_crop-1_upscale-1.jpg object_text: > Well, very well. I grew up in a house where people played chess, read poetry, or argued about poetry --- {{> digest}}